package de.intevation.artifactdatabase;

import de.intevation.artifactdatabase.rest.Standalone;

import java.io.File;

import java.net.MalformedURLException;

import org.apache.log4j.PropertyConfigurator;

import org.slf4j.bridge.SLF4JBridgeHandler;


/**
 * Starting point of the artifact database.
 *
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public class App
{
    public static final String LOG4J_PROPERTIES =
        "log4j.properties";

    public static final void configureLogging() {
        File configDir = Config.getConfigDirectory();
        File propFile = new File(configDir, LOG4J_PROPERTIES);

        if (propFile.isFile() && propFile.canRead()) {
            try {
                PropertyConfigurator.configure(propFile.toURI().toURL());
                SLF4JBridgeHandler.install();
            }
            catch (MalformedURLException mue) {
                mue.printStackTrace(System.err);
            }
        }
    }

    public static void main(String[] args) {

        configureLogging();

        FactoryBootstrap bootstrap = new FactoryBootstrap();

        bootstrap.boot();

        Backend backend = new Backend();

        ArtifactDatabaseImpl db = new ArtifactDatabaseImpl(
            bootstrap, backend);

        DatabaseCleaner cleaner = new DatabaseCleaner(
            bootstrap.getContext(), backend);

        bootstrap = null;

        backend.setCleaner(cleaner);

        cleaner.setFilter(db);

        cleaner.start();

        Standalone.startAsServer(db);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
